@@ -14,15 +14,93 @@ CREATE TABLE annotation (
 	PRIMARY KEY (tag, value, extensions, annotations)
 );
 
-CREATE TABLE class_definition (
-	name TEXT NOT NULL, 
-	title TEXT, 
-	definition_uri TEXT, 
-	local_names TEXT, 
+CREATE TABLE anonymous_class_expression (
 	extensions TEXT, 
 	annotations TEXT, 
 	description TEXT, 
 	alt_descriptions TEXT, 
+	title TEXT, 
+	deprecated TEXT, 
+	todos TEXT, 
+	notes TEXT, 
+	comments TEXT, 
+	examples TEXT, 
+	in_subset TEXT, 
+	from_schema TEXT, 
+	imported_from TEXT, 
+	see_also TEXT, 
+	deprecated_element_has_exact_replacement TEXT, 
+	deprecated_element_has_possible_replacement TEXT, 
+	is_a TEXT, 
+	any_of TEXT, 
+	exactly_one_of TEXT, 
+	none_of TEXT, 
+	all_of TEXT, 
+	slot_conditions TEXT, 
+	PRIMARY KEY (extensions, annotations, description, alt_descriptions, title, deprecated, todos, notes, comments, examples, in_subset, from_schema, imported_from, see_also, deprecated_element_has_exact_replacement, deprecated_element_has_possible_replacement, is_a, any_of, exactly_one_of, none_of, all_of, slot_conditions)
+);
+
+CREATE TABLE anonymous_slot_expression (
+	extensions TEXT, 
+	annotations TEXT, 
+	description TEXT, 
+	alt_descriptions TEXT, 
+	title TEXT, 
+	deprecated TEXT, 
+	todos TEXT, 
+	notes TEXT, 
+	comments TEXT, 
+	examples TEXT, 
+	in_subset TEXT, 
+	from_schema TEXT, 
+	imported_from TEXT, 
+	see_also TEXT, 
+	deprecated_element_has_exact_replacement TEXT, 
+	deprecated_element_has_possible_replacement TEXT, 
+	range TEXT, 
+	range_expression TEXT, 
+	required BOOLEAN, 
+	recommended BOOLEAN, 
+	minimum_value INTEGER, 
+	maximum_value INTEGER, 
+	pattern TEXT, 
+	equals_string TEXT, 
+	equals_string_in TEXT, 
+	equals_number INTEGER, 
+	equals_expression TEXT, 
+	minimum_cardinality INTEGER, 
+	maximum_cardinality INTEGER, 
+	has_member TEXT, 
+	all_members TEXT, 
+	none_of TEXT, 
+	exactly_one_of TEXT, 
+	any_of TEXT, 
+	all_of TEXT, 
+	PRIMARY KEY (extensions, annotations, description, alt_descriptions, title, deprecated, todos, notes, comments, examples, in_subset, from_schema, imported_from, see_also, deprecated_element_has_exact_replacement, deprecated_element_has_possible_replacement, range, range_expression, required, recommended, minimum_value, maximum_value, pattern, equals_string, equals_string_in, equals_number, equals_expression, minimum_cardinality, maximum_cardinality, has_member, all_members, none_of, exactly_one_of, any_of, all_of)
+);
+
+CREATE TABLE anonymous_type_expression (
+	pattern TEXT, 
+	equals_string TEXT, 
+	equals_string_in TEXT, 
+	equals_number INTEGER, 
+	none_of TEXT, 
+	exactly_one_of TEXT, 
+	any_of TEXT, 
+	all_of TEXT, 
+	PRIMARY KEY (pattern, equals_string, equals_string_in, equals_number, none_of, exactly_one_of, any_of, all_of)
+);
+
+CREATE TABLE class_definition (
+	name TEXT NOT NULL, 
+	definition_uri TEXT, 
+	local_names TEXT, 
+	conforms_to TEXT, 
+	extensions TEXT, 
+	annotations TEXT, 
+	description TEXT, 
+	alt_descriptions TEXT, 
+	title TEXT, 
 	deprecated TEXT, 
 	examples TEXT, 
 	in_subset TEXT, 
@@ -49,6 +127,11 @@ CREATE TABLE class_definition (
 	is_a TEXT, 
 	mixins TEXT, 
 	apply_to TEXT, 
+	any_of TEXT, 
+	exactly_one_of TEXT, 
+	none_of TEXT, 
+	all_of TEXT, 
+	slot_conditions TEXT, 
 	PRIMARY KEY (name), 
 	FOREIGN KEY(is_a) REFERENCES class_definition (name)
 );
@@ -81,6 +164,7 @@ CREATE TABLE permissible_value (
 	extensions TEXT, 
 	annotations TEXT, 
 	alt_descriptions TEXT, 
+	title TEXT, 
 	deprecated TEXT, 
 	examples TEXT, 
 	in_subset TEXT, 
@@ -94,13 +178,14 @@ CREATE TABLE permissible_value (
 
 CREATE TABLE subset_definition (
 	name TEXT NOT NULL, 
-	title TEXT, 
 	definition_uri TEXT, 
 	local_names TEXT, 
+	conforms_to TEXT, 
 	extensions TEXT, 
 	annotations TEXT, 
 	description TEXT, 
 	alt_descriptions TEXT, 
+	title TEXT, 
 	deprecated TEXT, 
 	examples TEXT, 
 	in_subset TEXT, 
@@ -113,13 +198,14 @@ CREATE TABLE subset_definition (
 
 CREATE TABLE type_definition (
 	name TEXT NOT NULL, 
-	title TEXT, 
 	definition_uri TEXT, 
 	local_names TEXT, 
+	conforms_to TEXT, 
 	extensions TEXT, 
 	annotations TEXT, 
 	description TEXT, 
 	alt_descriptions TEXT, 
+	title TEXT, 
 	deprecated TEXT, 
 	examples TEXT, 
 	in_subset TEXT, 
@@ -132,25 +218,79 @@ CREATE TABLE type_definition (
 	uri TEXT, 
 	repr TEXT, 
 	pattern TEXT, 
+	equals_string TEXT, 
+	equals_number INTEGER, 
+	none_of TEXT, 
+	exactly_one_of TEXT, 
+	any_of TEXT, 
+	all_of TEXT, 
 	PRIMARY KEY (name), 
 	FOREIGN KEY(typeof) REFERENCES type_definition (name)
 );
 
-CREATE TABLE unique_key (
-	unique_key_slots TEXT NOT NULL, 
-	extensions TEXT, 
-	annotations TEXT, 
-	PRIMARY KEY (unique_key_slots, extensions, annotations)
-);
-
-CREATE TABLE schema_definition (
-	title TEXT, 
-	definition_uri TEXT, 
-	local_names TEXT, 
+CREATE TABLE class_rule (
+	preconditions TEXT, 
+	postconditions TEXT, 
+	elseconditions TEXT, 
+	bidirectional BOOLEAN, 
+	open_world BOOLEAN, 
+	precedence INTEGER, 
+	deactivated BOOLEAN, 
 	extensions TEXT, 
 	annotations TEXT, 
 	description TEXT, 
 	alt_descriptions TEXT, 
+	title TEXT, 
+	deprecated TEXT, 
+	todos TEXT, 
+	notes TEXT, 
+	comments TEXT, 
+	examples TEXT, 
+	in_subset TEXT, 
+	from_schema TEXT, 
+	imported_from TEXT, 
+	see_also TEXT, 
+	deprecated_element_has_exact_replacement TEXT, 
+	deprecated_element_has_possible_replacement TEXT, 
+	class_definition_name TEXT, 
+	PRIMARY KEY (preconditions, postconditions, elseconditions, bidirectional, open_world, precedence, deactivated, extensions, annotations, description, alt_descriptions, title, deprecated, todos, notes, comments, examples, in_subset, from_schema, imported_from, see_also, deprecated_element_has_exact_replacement, deprecated_element_has_possible_replacement, class_definition_name), 
+	FOREIGN KEY(class_definition_name) REFERENCES class_definition (name)
+);
+
+CREATE TABLE classification_rule (
+	instance_of TEXT, 
+	slot_conditions TEXT, 
+	extensions TEXT, 
+	annotations TEXT, 
+	description TEXT, 
+	alt_descriptions TEXT, 
+	title TEXT, 
+	deprecated TEXT, 
+	todos TEXT, 
+	notes TEXT, 
+	comments TEXT, 
+	examples TEXT, 
+	in_subset TEXT, 
+	from_schema TEXT, 
+	imported_from TEXT, 
+	see_also TEXT, 
+	deprecated_element_has_exact_replacement TEXT, 
+	deprecated_element_has_possible_replacement TEXT, 
+	class_definition_name TEXT, 
+	PRIMARY KEY (instance_of, slot_conditions, extensions, annotations, description, alt_descriptions, title, deprecated, todos, notes, comments, examples, in_subset, from_schema, imported_from, see_also, deprecated_element_has_exact_replacement, deprecated_element_has_possible_replacement, class_definition_name), 
+	FOREIGN KEY(instance_of) REFERENCES class_definition (name), 
+	FOREIGN KEY(class_definition_name) REFERENCES class_definition (name)
+);
+
+CREATE TABLE schema_definition (
+	definition_uri TEXT, 
+	local_names TEXT, 
+	conforms_to TEXT, 
+	extensions TEXT, 
+	annotations TEXT, 
+	description TEXT, 
+	alt_descriptions TEXT, 
+	title TEXT, 
 	deprecated TEXT, 
 	examples TEXT, 
 	in_subset TEXT, 
@@ -179,13 +319,14 @@ CREATE TABLE schema_definition (
 
 CREATE TABLE slot_definition (
 	name TEXT NOT NULL, 
-	title TEXT, 
 	definition_uri TEXT, 
 	local_names TEXT, 
+	conforms_to TEXT, 
 	extensions TEXT, 
 	annotations TEXT, 
 	description TEXT, 
 	alt_descriptions TEXT, 
+	title TEXT, 
 	deprecated TEXT, 
 	examples TEXT, 
 	in_subset TEXT, 
@@ -203,14 +344,11 @@ CREATE TABLE slot_definition (
 	string_serialization TEXT, 
 	singular_name TEXT, 
 	domain TEXT, 
-	range TEXT, 
 	slot_uri TEXT, 
 	multivalued BOOLEAN, 
 	inherited BOOLEAN, 
 	readonly TEXT, 
 	ifabsent TEXT, 
-	required BOOLEAN, 
-	recommended BOOLEAN, 
 	inlined BOOLEAN, 
 	inlined_as_list BOOLEAN, 
 	"key" BOOLEAN, 
@@ -226,12 +364,27 @@ CREATE TABLE slot_definition (
 	role TEXT, 
 	is_usage_slot BOOLEAN, 
 	usage_slot_name TEXT, 
-	minimum_value INTEGER, 
-	maximum_value INTEGER, 
-	pattern TEXT, 
 	is_a TEXT, 
 	mixins TEXT, 
 	apply_to TEXT, 
+	range TEXT, 
+	range_expression TEXT, 
+	required BOOLEAN, 
+	recommended BOOLEAN, 
+	minimum_value INTEGER, 
+	maximum_value INTEGER, 
+	pattern TEXT, 
+	equals_string TEXT, 
+	equals_number INTEGER, 
+	equals_expression TEXT, 
+	minimum_cardinality INTEGER, 
+	maximum_cardinality INTEGER, 
+	has_member TEXT, 
+	all_members TEXT, 
+	none_of TEXT, 
+	exactly_one_of TEXT, 
+	any_of TEXT, 
+	all_of TEXT, 
 	PRIMARY KEY (name), 
 	FOREIGN KEY(domain) REFERENCES class_definition (name), 
 	FOREIGN KEY(subproperty_of) REFERENCES slot_definition (name), 
@@ -239,6 +392,29 @@ CREATE TABLE slot_definition (
 	FOREIGN KEY(is_a) REFERENCES slot_definition (name)
 );
 
+CREATE TABLE unique_key (
+	unique_key_slots TEXT NOT NULL, 
+	extensions TEXT, 
+	annotations TEXT, 
+	description TEXT, 
+	alt_descriptions TEXT, 
+	title TEXT, 
+	deprecated TEXT, 
+	todos TEXT, 
+	notes TEXT, 
+	comments TEXT, 
+	examples TEXT, 
+	in_subset TEXT, 
+	from_schema TEXT, 
+	imported_from TEXT, 
+	see_also TEXT, 
+	deprecated_element_has_exact_replacement TEXT, 
+	deprecated_element_has_possible_replacement TEXT, 
+	class_definition_name TEXT, 
+	PRIMARY KEY (unique_key_slots, extensions, annotations, description, alt_descriptions, title, deprecated, todos, notes, comments, examples, in_subset, from_schema, imported_from, see_also, deprecated_element_has_exact_replacement, deprecated_element_has_possible_replacement, class_definition_name), 
+	FOREIGN KEY(class_definition_name) REFERENCES class_definition (name)
+);
+
 CREATE TABLE class_definition_id_prefixes (
 	backref_id TEXT, 
 	id_prefixes TEXT, 
@@ -526,15 +702,23 @@ CREATE TABLE type_definition_see_also (
 	FOREIGN KEY(backref_id) REFERENCES type_definition (name)
 );
 
+CREATE TABLE type_definition_equals_string_in (
+	backref_id TEXT, 
+	equals_string_in TEXT, 
+	PRIMARY KEY (backref_id, equals_string_in), 
+	FOREIGN KEY(backref_id) REFERENCES type_definition (name)
+);
+
 CREATE TABLE enum_definition (
 	name TEXT NOT NULL, 
-	title TEXT, 
 	definition_uri TEXT, 
 	local_names TEXT, 
+	conforms_to TEXT, 
 	extensions TEXT, 
 	annotations TEXT, 
 	description TEXT, 
 	alt_descriptions TEXT, 
+	title TEXT, 
 	deprecated TEXT, 
 	examples TEXT, 
 	in_subset TEXT, 
@@ -756,6 +940,13 @@ CREATE TABLE slot_definition_values_from (
 	FOREIGN KEY(backref_id) REFERENCES slot_definition (name)
 );
 
+CREATE TABLE slot_definition_equals_string_in (
+	backref_id TEXT, 
+	equals_string_in TEXT, 
+	PRIMARY KEY (backref_id, equals_string_in), 
+	FOREIGN KEY(backref_id) REFERENCES slot_definition (name)
+);
+
 CREATE TABLE enum_definition_id_prefixes (
 	backref_id TEXT, 
 	id_prefixes TEXT, 
